package session.destory.dao;

import java.io.Serializable;
import java.util.List;

import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.criterion.DetachedCriteria;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

@Transactional
public abstract class AbstractHibernateDao<T> {

	private SessionFactory sessionFactory;
	private Class<T> clazz;

	public AbstractHibernateDao(Class<T> clazz) {
		this.clazz = clazz;
	}

	@Autowired
	public void setSessionFactory(SessionFactory sessionFactory) {
		this.sessionFactory = sessionFactory;
	}

	protected Class<T> getClazz() {
		return this.clazz;
	}

	protected Session getSession() {
		return this.sessionFactory.getCurrentSession();
	}

	@SuppressWarnings("unchecked")
	protected List<T> list(DetachedCriteria c) {
		return c.getExecutableCriteria(getSession()).list();
	}

	@SuppressWarnings("unchecked")
	public T getById(Serializable id) {
		return (T) getSession().get(this.clazz, id);
	}

	public T insert(T entity) {
		getSession().persist(entity);
		return entity;
	}

	public T update(T entity) {
		getSession().update(entity);
		return entity;
	}

	public void delete(T entity) {
		getSession().delete(entity);
	}

}
