package session.destory.security;

import java.io.IOException;
import java.util.Date;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.authentication.SavedRequestAwareAuthenticationSuccessHandler;

import session.destory.entity.LoginHistory;
import session.destory.service.LoginHistoryService;

/**
 * 로그인 성공 후 접속 이력을 남기기 위한 핸들러
 * @author Antop
 *
 */
public class AuthenticationSuccessHandler extends SavedRequestAwareAuthenticationSuccessHandler {

	@Autowired
	private LoginHistoryService loginHistortyService;
	
	@Override
	public void onAuthenticationSuccess(HttpServletRequest request, HttpServletResponse response,
			Authentication authentication) throws ServletException, IOException {
		super.onAuthenticationSuccess(request, response, authentication);
		
		LoginToken loginToken = (LoginToken) authentication.getPrincipal();
		
		// create login histroy instance
		LoginHistory lh = new LoginHistory();
		lh.setUser(loginToken.getUser());
		lh.setIpv4(request.getRemoteAddr());
		lh.setLoginDate(new Date());
		
		// regsiter -> db insert
		loginHistortyService.register(lh);
		
		// set
		loginToken.setHistory(lh);
	}
	
}
